import time
import types
import urlparse

from urlnorm import InvalidUrl, norm

from stats_collector import config

log_file = open(config.LOG_FILE, 'a')
INVALID_REALM = 'INVALID_REALM'


def time_measure(func, *args, **kwd):
    """Call and measures time of inner function/method.

    Write result to log file and if DEBUG is True that to stdout, too.
    """
    t1 = time.time()
    result = func(*args, **kwd)
    t_diff = time.time() - t1

    if isinstance(func, types.FunctionType):
        f_name = func.func_name
    else:
        f_name = '%s.%s' % (func.im_class.__name__, func.im_func.func_name)

    log_file.write('%-40s %10.3f\n' % (f_name + ':', t_diff))
    if config.DEBUG:
        print '%-40s %10.3f' % (f_name + ':', t_diff)

    return result


def truncate_provider(provider):
    """Truncate provider to domain part only."""
    try:
        provider = norm(provider)
    except InvalidUrl:
        return INVALID_REALM
    else:
        provider_tuple = urlparse.urlsplit(provider)
        domain_part = urlparse.urlunsplit((provider_tuple.scheme, provider_tuple.netloc, '', '', ''))
        if len(domain_part) < 255:
            return domain_part
        else:
            return INVALID_REALM
